@@ -12,13 +12,13 @@ has format => sub {
     ? Mojo::URL->new($self->url)->path->[-1]
     : (split m!(\\|/)!, $self->url)[-1];
 
-  return $name =~ /\.(\w+)$/ ? $1 : '';
+  return $name =~ /\.(\w+)$/ ? lc $1 : '';
 };
 
 has minified => sub { shift->url =~ /\bmin\b/ ? 1 : 0 };
 has mtime => sub { shift->_asset->mtime };
 
-has tag_helper => sub { shift->format eq 'js' ? 'javascript' : 'stylesheet' };
+sub tag_helper { warn "DEPRECATED in v1.17! This attribute does nothing." }
 
 has _asset => sub {
   my $self = shift;
@@ -69,6 +69,8 @@ sub get_chunk { shift->_asset->get_chunk(@_) }
 sub path { $_[0]->_asset->isa('Mojo::Asset::File') ? $_[0]->_asset->path : '' }
 sub size { $_[0]->_asset->size }
 
+sub url_for { $_[1]->url_for(assetpack => $_[0]->TO_JSON); }
+
 sub _reset {
   my $self = shift;
   delete $self->{$_} for qw(checksum format mtime);
@@ -142,14 +144,7 @@ Returns the basename of L</url>, without extension.
 
 =head2 tag_helper
 
-  $self = $self->tag_helper("stylesheet");
-  $str = $self->tag_helper;
-
-Used to get the Mojolicious L<tag helper|Mojolicious::Plugin::TagHelpers> which
-should be used to render this asset.
-
-This could be set to "image" by a pipe, but defaults to either "stylesheet" or
-"javascript", based on L</format>.
+Replaced by L<Mojolicious::Plugin::AssetPack/tag_for>.
 
 =head2 url
 
@@ -190,6 +185,13 @@ Returns the path to the asset, if it exists on disk.
 
 See L<Mojo::Asset/size>.
 
+=head2 url_for
+
+  $url = $self->url_for($c);
+
+Returns a L<Mojo::URL> object for this asset. C<$c> need to be a
+L<Mojolicious::Controller>.
+
 =head2 FROM_JSON
 
   $self = $self->FROM_JSON($hash_ref);
